@@ -10,43 +10,45 @@ from nesoni import config
 Produce 3D models using the output of "demakein design-*-flute:"
 """)
 @config.Bool_flag('open', 'Open both ends, thus requiring a cork.')
-@config.Bool_flag('mill', 'Create shapes for milling (rather than 3D printing).')
-@config.Float_flag('mill_diameter', 'Milling: Bit diameter for milling (affects gap size when packing pieces).')
-@config.Float_flag('mill_length', 'Milling: Wood length for milling.')
-@config.Float_flag('mill_width', 'Milling: Wood width for milling.')
-@config.Float_flag('mill_thickness', 'Milling: Wood thickness for milling.')
-@config.Int_flag('mill_scheme', 'Milling: Division scheme for milling.\nValid values: 2 3 4')
+#@config.Bool_flag('mill', 'Create shapes for milling (rather than 3D printing).')
+#@config.Float_flag('mill_diameter', 'Milling: Bit diameter for milling (affects gap size when packing pieces).')
+#@config.Float_flag('mill_length', 'Milling: Wood length for milling.')
+#@config.Float_flag('mill_width', 'Milling: Wood width for milling.')
+#@config.Float_flag('mill_thickness', 'Milling: Wood thickness for milling.')
+#@config.Int_flag('mill_scheme', 'Milling: Division scheme for milling.\nValid values: 2 3 4')
+@config.Float_flag('emb_squareness', 'Squareness of embouchure hole, larger = squarer.')
+@config.Float_flag('emb_aspect', 'Aspect ratio of embouchure hole, 1 = square, larger = wider.')
 @config.Bool_flag('decorate', 'Add some decorations')
-class Make_flute(make.Make_instrument):
-    gap = 0.35
-
-    mill = False
+class Make_flute(make.Make_millable_instrument):
+    #mill = False
     open = False
 
-    mill_diameter = 3.0    
-    mill_length = 180.0
-    mill_width = 130.0
-    mill_thickness = 19.0
-    mill_scheme = 4
-    
+    #mill_diameter = 3.0    
+    #mill_length = 180.0
+    #mill_width = 130.0
+    #mill_thickness = 19.0
+    #mill_scheme = 4
+
+    emb_squareness = 0.0
+    emb_aspect = 1.5    
     decorate = False
     
-    SCHEMES = {
-        2 : [
-            [ 0.0, 0.6, 1.0 ],
-            [ 0.0, 0.4, 1.0 ],
-        ],
-        
-        3 : [
-            [ 0.0, 0.3, 0.6, 1.0 ],
-            [ 0.0, 0.4, 0.7, 1.0 ],
-        ],
-        
-        4 : [
-            [ 0.0, 0.2, 0.45, 0.7, 1.0 ],
-            [ 0.0, 0.3, 0.55, 0.8, 1.0 ],
-        ],
-    }
+    #SCHEMES = {
+    #    2 : [
+    #        [ 0.0, 0.6, 1.0 ],
+    #        [ 0.0, 0.4, 1.0 ],
+    #    ],
+    #    
+    #    3 : [
+    #        [ 0.0, 0.3, 0.6, 1.0 ],
+    #        [ 0.0, 0.4, 0.7, 1.0 ],
+    #    ],
+    #    
+    #    4 : [
+    #        [ 0.0, 0.2, 0.45, 0.7, 1.0 ],
+    #        [ 0.0, 0.3, 0.55, 0.8, 1.0 ],
+    #    ],
+    #}
     
     def run(self):
         working = self.working
@@ -83,13 +85,20 @@ class Make_flute(make.Make_instrument):
                outer_profile = outer_profile + deco_profile
 
 
+        if self.emb_aspect > 1.0:
+            emb_xpad = self.emb_squareness
+            emb_ypad = (emb_xpad+1.0)*self.emb_aspect-1.0
+        else:
+            emb_ypad = self.emb_squareness
+            emb_xpad = (emb_ypad+1.0)/self.emb_aspect-1.0
+
         self.make_instrument(
              inner_profile=inner_profile, outer_profile=outer_profile, 
              hole_positions=spec.hole_positions, hole_diameters=spec.hole_diameters, hole_vert_angles=spec.hole_angles, 
              #hole_horiz_angles=[0.0]*7,
              hole_horiz_angles=[0.0, 0.0, 0.0, 5.0, 0.0, 0.0, 0.0],
-             xpad=[0.0]*7, 
-             ypad=[0.0]*6+[0.5], #[0.75], 
+             xpad=[0.0]*6+[emb_xpad], 
+             ypad=[0.0]*6+[emb_ypad],
              with_fingerpad=[True]*6+[False])
         
         #instrument = shape.extrude_profile(outer_profile)
@@ -133,29 +142,31 @@ class Make_flute(make.Make_instrument):
         #instrument.rotate(0,0,1, 180)
         #self.save(instrument,'instrument')
         
-        if self.mill:        
-            shapes = pack.cut_and_pack(
-                working.outside, working.bore,
-                self.SCHEMES[self.mill_scheme][0], self.SCHEMES[self.mill_scheme][1],
-                xsize=self.mill_length, 
-                ysize=self.mill_width, 
-                zsize=self.mill_thickness,
-                bit_diameter=self.mill_diameter,
-                save=self.save,
-            )
+        self.make_parts(up = False)
         
-        else:
-            for division in designer.divisions:
-                cuts = [ ]
-                for hole, above in division:
-                    if hole >= 0:
-                        cut = spec.hole_positions[hole] + 2*spec.hole_diameters[hole]
-                    else:
-                        cut = 0.0
-                    cut += (length-cut)*above
-                    cuts.append(cut)
-                    
-                self.segment(cuts, length, up=False)
+        #if self.mill:        
+        #    shapes = pack.cut_and_pack(
+        #        working.outside, working.bore,
+        #        self.SCHEMES[self.mill_scheme][0], self.SCHEMES[self.mill_scheme][1],
+        #        xsize=self.mill_length, 
+        #        ysize=self.mill_width, 
+        #        zsize=self.mill_thickness,
+        #        bit_diameter=self.mill_diameter,
+        #        save=self.save,
+        #    )
+        #
+        #else:
+        #    for division in designer.divisions:
+        #        cuts = [ ]
+        #        for hole, above in division:
+        #            if hole >= 0:
+        #                cut = spec.hole_positions[hole] + 2*spec.hole_diameters[hole]
+        #            else:
+        #                cut = 0.0
+        #            cut += (length-cut)*above
+        #            cuts.append(cut)
+        #            
+        #        self.segment(cuts, up=False)
 
 
             #cut1 = min(spec.hole_positions[3],spec.inner_hole_positions[3])-spec.hole_diameters[3] * 0.75
